@@ -1,9 +1,10 @@
-import os
 import json
+import os
 import sqlite3
 
 # Don't alter this. Unless you want to deal with permission issues in other places
-CACHED_DATABASE = os.path.expanduser("~") + "/.cambd-cache.db"
+CACHED_DATABASE = os.path.expanduser("~") + "/.cache/cambd/dictionary.db"
+os.makedirs(os.path.dirname(CACHED_DATABASE), exist_ok=True)
 con = sqlite3.connect(CACHED_DATABASE)
 
 
